@@ -1,28 +1,16 @@
-try:
-    # Python 3.8+
-    from importlib import metadata
-except ImportError:
-    import importlib_metadata as metadata
-
 import psutil
 from rich import box
 from rich.panel import Panel
 from rich.table import Table
 from textual.widget import Widget
 
+from .__about__ import __version__
 from ._helpers import sizeof_fmt
 
 
 class ProcsList(Widget):
     def on_mount(self):
-        self.tiptop_string = "tiptop"
-        try:
-            __version__ = metadata.version("tiptop")
-        except metadata.PackageNotFoundError:
-            pass
-        else:
-            self.tiptop_string += f" v{__version__}"
-
+        self.tiptop_string = f"tiptop v{__version__}"
         self.max_num_procs = 100
         self.collect_data()
         self.set_interval(6.0, self.collect_data)
